Index: channels/chan_motif.c
===================================================================
--- channels/chan_motif.c	(revision 381715)
+++ channels/chan_motif.c	(working copy)
@@ -2719,7 +2719,7 @@
 	ast_format_cap_add_all_by_type(jingle_tech.capabilities, AST_FORMAT_TYPE_AUDIO);
 
 	if (aco_process_config(&cfg_info, 0)) {
-		ast_log(LOG_ERROR, "Unable to read config file motif.conf. Not loading module.\n");
+		ast_log(LOG_ERROR, "Unable to read config file motif.conf. Module loaded but not running.\n");
 		aco_info_destroy(&cfg_info);
 		return AST_MODULE_LOAD_DECLINE;
 	}
Index: main/loader.c
===================================================================
--- main/loader.c	(revision 381715)
+++ main/loader.c	(working copy)
@@ -1240,7 +1240,7 @@
 	AST_LIST_UNLOCK(&updaters);
 }
 
-int ast_update_module_list(int (*modentry)(const char *module, const char *description, int usecnt, const char *like),
+int ast_update_module_list(int (*modentry)(const char *module, const char *description, int usecnt, const char *status, const char *like),
 			   const char *like)
 {
 	struct ast_module *cur;
@@ -1251,7 +1251,8 @@
 		unlock = 0;
 
 	AST_LIST_TRAVERSE(&module_list, cur, entry) {
-		total_mod_loaded += modentry(cur->resource, cur->info->description, cur->usecount, like);
+		total_mod_loaded += modentry(cur->resource, cur->info->description, cur->usecount,
+						cur->flags.running ? "Running" : "Not Running", like);
 	}
 
 	if (unlock)
Index: main/cli.c
===================================================================
--- main/cli.c	(revision 381715)
+++ main/cli.c	(working copy)
@@ -651,17 +651,17 @@
 	return CLI_SUCCESS;
 }
 
-#define MODLIST_FORMAT  "%-30s %-40.40s %-10d\n"
-#define MODLIST_FORMAT2 "%-30s %-40.40s %-10s\n"
+#define MODLIST_FORMAT  "%-30s %-40.40s %-10d %s\n"
+#define MODLIST_FORMAT2 "%-30s %-40.40s %-10s %s\n"
 
 AST_MUTEX_DEFINE_STATIC(climodentrylock);
 static int climodentryfd = -1;
 
-static int modlist_modentry(const char *module, const char *description, int usecnt, const char *like)
+static int modlist_modentry(const char *module, const char *description, int usecnt, const char *status, const char *like)
 {
 	/* Comparing the like with the module */
 	if (strcasestr(module, like) ) {
-		ast_cli(climodentryfd, MODLIST_FORMAT, module, description, usecnt);
+		ast_cli(climodentryfd, MODLIST_FORMAT, module, description, usecnt, status);
 		return 1;
 	}
 	return 0;
@@ -788,7 +788,7 @@
 
 	ast_mutex_lock(&climodentrylock);
 	climodentryfd = a->fd; /* global, protected by climodentrylock */
-	ast_cli(a->fd, MODLIST_FORMAT2, "Module", "Description", "Use Count");
+	ast_cli(a->fd, MODLIST_FORMAT2, "Module", "Description", "Use Count", "Status");
 	ast_cli(a->fd,"%d modules loaded\n", ast_update_module_list(modlist_modentry, like));
 	climodentryfd = -1;
 	ast_mutex_unlock(&climodentrylock);
Index: res/snmp/agent.c
===================================================================
--- res/snmp/agent.c	(revision 381715)
+++ res/snmp/agent.c	(working copy)
@@ -760,7 +760,7 @@
 	return NULL;
 }
 
-static int countmodule(const char *mod, const char *desc, int use, const char *like)
+static int countmodule(const char *mod, const char *desc, int use, const char *status, const char *like)
 {
 	return 1;
 }

Index: include/asterisk/module.h
===================================================================
--- include/asterisk/module.h	(revision 381715)
+++ include/asterisk/module.h	(working copy)
@@ -110,17 +110,17 @@
  */
 void ast_update_use_count(void);
 
 /*! 
  * \brief Ask for a list of modules, descriptions, and use counts.
  * \param modentry A callback to an updater function.
  * \param like
  *
  * For each of the modules loaded, modentry will be executed with the resource,
  * description, and usecount values of each particular module.
- * 
+ *
  * \return the number of modules loaded
  */
-int ast_update_module_list(int (*modentry)(const char *module, const char *description, int usecnt, const char *like),
+int ast_update_module_list(int (*modentry)(const char *module, const char *description, int usecnt, const char *status, const char *like),
 			   const char *like);
 
 /*!
@@ -110,17 +110,17 @@
 void ast_update_use_count(void);
 
-/*! 
- * \brief Ask for a list of modules, descriptions, and use counts.
+/*!
+ * \brief Ask for a list of modules, descriptions, use counts and status.
  * \param modentry A callback to an updater function.
  * \param like